@@ -26,14 +26,17 @@ pub enum Control {
     IncreaseWidth,
     DecreaseWidth,
     Find(String),
+    FindLikeCell,
     Filter(String),
     FilterColumns(String),
+    FilterLikeCell,
     Quit,
     BufferContent(Input),
     BufferReset,
     Select,
+    CopySelection,
     ToggleSelectionType,
-    ToggleLineWrap,
+    ToggleLineWrap(bool),
     ToggleSort,
     Reset,
     Help,
@@ -124,6 +127,10 @@ impl InputHandler {
                 KeyCode::Char('>') => Control::IncreaseWidth,
                 KeyCode::Char('<') => Control::DecreaseWidth,
                 KeyCode::Char('r') => Control::Reset,
+                KeyCode::Char('?') => Control::Help,
+                KeyCode::Char('#') => Control::FindLikeCell,
+                KeyCode::Char('@') => Control::FilterLikeCell,
+                KeyCode::Char('y') => Control::CopySelection,
                 _ => Control::Nothing,
             },
             KeyModifiers::SHIFT => match key_event.code {
@@ -240,7 +247,11 @@ impl InputHandler {
             }
             KeyCode::Char('S') => {
                 self.reset_buffer();
-                Control::ToggleLineWrap
+                Control::ToggleLineWrap(false)
+            }
+            KeyCode::Char('W') | KeyCode::Char('w') => {
+                self.reset_buffer();
+                Control::ToggleLineWrap(true)
             }
             KeyCode::Char(x) => {
                 self.reset_buffer();
