@@ -141,18 +141,22 @@ impl<'a> CsvTable<'a> {
                 let num_lines = match column_widths.get(j) {
                     Some(w) => {
                         let usable_width = (*w).saturating_sub(NUM_SPACES_BETWEEN_COLUMNS);
-                        let spans = [Span::styled(content.as_str(), Style::default())];
-                        let mut line_wrapper =
-                            wrap::LineWrapper::new(&spans, usable_width as usize, is_word_wrap);
-                        let mut num_lines = 0;
-                        loop {
-                            line_wrapper.next();
-                            num_lines += 1;
-                            if line_wrapper.finished() {
-                                break;
+                        if usable_width > 0 {
+                            let spans = [Span::styled(content.as_str(), Style::default())];
+                            let mut line_wrapper =
+                                wrap::LineWrapper::new(&spans, usable_width as usize, is_word_wrap);
+                            let mut num_lines = 0;
+                            loop {
+                                line_wrapper.next();
+                                num_lines += 1;
+                                if line_wrapper.finished() {
+                                    break;
+                                }
                             }
+                            num_lines
+                        } else {
+                            1
                         }
-                        num_lines
                     }
                     None => 1,
                 };
@@ -415,9 +419,9 @@ impl<'a> CsvTable<'a> {
             }
             remaining_width = remaining_width.saturating_sub(hlen);
         }
-        state.set_num_cols_rendered(num_cols_rendered);
+        state.num_cols_rendered = max(state.num_cols_rendered, num_cols_rendered);
         state.set_more_cols_to_show(has_more_cols_to_show);
-        state.col_ending_pos_x = col_ending_pos_x;
+        state.col_ending_pos_x = max(state.col_ending_pos_x, col_ending_pos_x);
         row_height
     }
 
@@ -517,7 +521,7 @@ impl<'a> CsvTable<'a> {
                     }
                 }
                 let padding_width = min(
-                    (effective_width as usize).saturating_sub(line.width()) + buffer_space,
+                    (effective_width as usize + buffer_space).saturating_sub(line.width()),
                     width as usize,
                 );
                 if padding_width > 0 {
@@ -546,42 +550,37 @@ impl<'a> CsvTable<'a> {
         }
     }
 
-    fn format_input(&self, input: &Input) -> String {
-        let chars_before: String = input.value().chars().take(input.cursor()).collect();
-        let chars_after: String = input.value().chars().skip(input.cursor()).collect();
-        format!("{chars_before}█{chars_after}")
-    }
-
-    fn render_status(&self, area: Rect, buf: &mut Buffer, state: &CsvTableState) {
+    fn render_status(&self, area: Rect, buf: &mut Buffer, state: &mut CsvTableState) {
         // Content of status line (separator already plotted elsewhere)
         let style = Style::default().fg(Color::Rgb(128, 128, 128));
         let mut content: String;
+        state.cursor_xy = None;
         if let Some(msg) = &state.transient_message {
             content = msg.to_owned();
         } else if let BufferState::Enabled(buffer_mode, input) = &state.buffer_content {
-            content = input.value().to_string();
-            let format_buffer = |prefix: &str| {
-                format!(
-                    "{prefix}: {formatted_input}",
-                    formatted_input = self.format_input(input)
-                )
+            let get_prefix = |&input_mode| {
+                let prefix = match input_mode {
+                    InputMode::GotoLine => "Go to line",
+                    InputMode::Find => "Find",
+                    InputMode::Filter => "Filter",
+                    InputMode::FilterColumns => "Columns regex",
+                    InputMode::Option => "Option",
+                    _ => "",
+                };
+                if prefix.is_empty() {
+                    "".to_string()
+                } else {
+                    format!("{prefix}: ")
+                }
             };
-            match buffer_mode {
-                InputMode::GotoLine => {
-                    content = format_buffer("Go to line");
-                }
-                InputMode::Find => {
-                    content = format_buffer("Find");
-                }
-                InputMode::Filter => {
-                    content = format_buffer("Filter");
-                }
-                InputMode::FilterColumns => {
-                    content = format_buffer("Columns regex");
-                }
-                InputMode::Option => content = format_buffer("Option"),
-                _ => {}
-            }
+            let prefix = get_prefix(buffer_mode);
+            content = format!("{prefix}{}", input.value());
+            state.cursor_xy = Some((
+                area.x
+                    .saturating_add(prefix.len() as u16)
+                    .saturating_add(input.cursor() as u16),
+                area.bottom().saturating_sub(1),
+            ));
         } else {
             // Filename
             if let Some(f) = &state.filename {
@@ -591,10 +590,10 @@ impl<'a> CsvTable<'a> {
             }
 
             // Row / Col
-            let total_str = if state.total_line_number.is_some() {
-                format!("{}", state.total_line_number.unwrap())
-            } else {
-                "?".to_owned()
+            let total_str = match state.total_line_number {
+                Some((total, false)) => format!("{}", total),
+                Some((total, true)) => format!("{}+", total),
+                _ => "?".to_owned(),
             };
             let current_row;
             if let Some(selection) = &state.selection {
@@ -675,6 +674,8 @@ impl<'a> CsvTable<'a> {
             state.enable_line_wrap,
             state.is_word_wrap,
         );
+        state.num_cols_rendered = 0;
+        state.col_ending_pos_x = 0;
         // state.debug = format!("get_row_heights elapsed: {:?}", _tic.elapsed());
         // state.debug = format!("row_heights: {:?}, area_height: {:?}", row_heights, area.height);
         ViewLayout {
@@ -967,20 +968,20 @@ struct BordersState {
 }
 
 pub struct DebugStats {
-    rows_view_elapsed: Option<f64>,
+    rows_view_stats: Option<crate::view::PerfStats>,
     finder_elapsed: Option<f64>,
 }
 
 impl DebugStats {
     pub fn new() -> Self {
         DebugStats {
-            rows_view_elapsed: None,
+            rows_view_stats: None,
             finder_elapsed: None,
         }
     }
 
-    pub fn rows_view_elapsed(&mut self, elapsed: Option<u128>) {
-        self.rows_view_elapsed = elapsed.map(|e| e as f64 / 1000.0);
+    pub fn rows_view_perf(&mut self, stats: Option<crate::view::PerfStats>) {
+        self.rows_view_stats = stats;
     }
 
     pub fn finder_elapsed(&mut self, elapsed: Option<u128>) {
@@ -989,8 +990,21 @@ impl DebugStats {
 
     pub fn status_line(&self) -> Option<String> {
         let mut line = "[".to_string();
-        if let Some(elapsed) = self.rows_view_elapsed {
-            line += format!("rows:{elapsed}ms").as_str();
+        if let Some(stats) = &self.rows_view_stats {
+            line += format!(
+                "rows:{:.3}ms pos:{}us npos:{} seek:{} parse:{}",
+                stats.elapsed.as_micros() as f64 / 1000.0,
+                stats
+                    .reader_stats
+                    .pos_table_elapsed
+                    .as_ref()
+                    .map(|e| e.as_micros())
+                    .unwrap_or(0),
+                stats.reader_stats.pos_table_entry,
+                stats.reader_stats.num_seek,
+                stats.reader_stats.num_parsed_record
+            )
+            .as_str();
         }
         if let Some(elapsed) = self.finder_elapsed {
             line += format!(" finder:{elapsed}ms").as_str();
@@ -1011,7 +1025,7 @@ pub struct CsvTableState {
     pub num_cols_rendered: u64,
     pub more_cols_to_show: bool,
     filename: Option<String>,
-    total_line_number: Option<usize>,
+    total_line_number: Option<(usize, bool)>,
     total_cols: usize,
     pub debug_stats: DebugStats,
     buffer_content: BufferState,
@@ -1030,6 +1044,7 @@ pub struct CsvTableState {
     pub enable_line_wrap: bool,
     pub is_word_wrap: bool,
     pub column_width_overrides: ColumnWidthOverrides,
+    pub cursor_xy: Option<(u16, u16)>,
     pub debug: String,
 }
 
@@ -1065,6 +1080,7 @@ impl CsvTableState {
             enable_line_wrap: false,
             is_word_wrap: false,
             column_width_overrides: ColumnWidthOverrides::new(),
+            cursor_xy: None,
             debug: "".into(),
         }
     }
@@ -1085,12 +1101,8 @@ impl CsvTableState {
         self.more_cols_to_show
     }
 
-    fn set_num_cols_rendered(&mut self, n: u64) {
-        self.num_cols_rendered = n;
-    }
-
-    pub fn set_total_line_number(&mut self, n: usize) {
-        self.total_line_number = Some(n);
+    pub fn set_total_line_number(&mut self, n: usize, is_approx: bool) {
+        self.total_line_number = Some((n, is_approx));
     }
 
     pub fn set_total_cols(&mut self, n: usize) {
